@@ -177,6 +177,123 @@ gda_column_new (void)
 	return column;
 }
 
+/** 	 /**
+  * gda_column_copy 	 
+  * @column: column to get a copy from. 	 
+  * 	 
+  * Creates a new #GdaColumn object from an existing one. 	 
+  * Returns: a newly allocated #GdaColumn with a copy of the data 	 
+  * in @column. 	 
+  */ 	 
+ GdaColumn * 	 
+ gda_column_copy (GdaColumn *column) 	 
+ { 	 
+         GdaColumn *column_copy; 	 
+  	 
+         g_return_val_if_fail (GDA_IS_COLUMN (column), NULL); 	 
+  	 
+         column_copy = gda_column_new (); 	 
+         column_copy->priv->defined_size = column->priv->defined_size;
+	 if (column->priv->name)
+		 column_copy->priv->name = g_strdup (column->priv->name);
+	 if (column->priv->title)
+		 column_copy->priv->name = g_strdup (column->priv->title);
+	 if (column->priv->table)
+		 column_copy->priv->table = g_strdup (column->priv->table);
+	 if (column->priv->caption)
+		 column_copy->priv->caption = g_strdup (column->priv->caption);
+         column_copy->priv->scale = column->priv->scale;
+         column_copy->priv->gda_type = column->priv->gda_type;
+         column_copy->priv->allow_null = column->priv->allow_null;
+         column_copy->priv->primary_key = column->priv->primary_key;
+         column_copy->priv->unique_key = column->priv->unique_key;
+	 if (column->priv->references)
+		 column_copy->priv->references = g_strdup (column->priv->references);
+         column_copy->priv->auto_increment = column->priv->auto_increment;
+         column_copy->priv->auto_increment_start = column->priv->auto_increment_start;
+         column_copy->priv->auto_increment_step = column->priv->auto_increment_step;
+         column_copy->priv->position = column->priv->position;
+	 if (column->priv->default_value)
+		 column_copy->priv->default_value = gda_value_copy (column->priv->default_value);
+  	 
+         return column_copy; 	 
+ }
+
+/** 	 
+ * gda_column_equal: 	 
+ * @lhs: a #GdaColumn 	 
+ * @rhs: another #GdaColumn 	 
+ * 	 
+ * Tests whether two colums are equal. 	 
+ * 	 
+ * Return value: %TRUE if the columns contain the same information. 	 
+ */
+gboolean
+gda_column_equal (const GdaColumn *lhs, const GdaColumn *rhs) 	 
+{ 	 
+	g_return_val_if_fail (GDA_IS_COLUMN (lhs), FALSE); 	 
+	g_return_val_if_fail (GDA_IS_COLUMN (rhs), FALSE); 	 
+  	 
+	/* Compare every struct field: */ 	 
+	if ((lhs->priv->defined_size != rhs->priv->defined_size) || 	 
+	    (lhs->priv->scale != rhs->priv->scale) || 	 
+	    (lhs->priv->gda_type != rhs->priv->gda_type) || 	 
+	    (lhs->priv->allow_null != rhs->priv->allow_null) || 	 
+	    (lhs->priv->primary_key != rhs->priv->primary_key) || 	 
+	    (lhs->priv->unique_key != rhs->priv->unique_key) || 	 
+	    (lhs->priv->auto_increment != rhs->priv->auto_increment) || 	 
+	    (lhs->priv->auto_increment_step != rhs->priv->auto_increment_step) || 	 
+	    (lhs->priv->position != rhs->priv->position)) 	 
+		return FALSE; 	 
+  	 
+	/* Check the strings if they have are not null. 	 
+	   Then check whether one is null while the other is not, because strcmp can not do that. */ 	 
+	if ((lhs->priv->name && rhs->priv->name) 	 
+	    && (strcmp (lhs->priv->name, rhs->priv->name) != 0)) 	 
+		return FALSE; 	 
+  	 
+	if ((lhs->priv->name == 0) != (rhs->priv->name == 0)) 	 
+		return FALSE; 	 
+
+	if ((lhs->priv->title && rhs->priv->title) 	 
+	    && (strcmp (lhs->priv->title, rhs->priv->title) != 0)) 	 
+		return FALSE; 	 
+  	 
+	if ((lhs->priv->title == 0) != (rhs->priv->title == 0)) 	 
+		return FALSE; 	 
+  	 
+	if ((lhs->priv->table && rhs->priv->table) 	 
+	    && (strcmp (lhs->priv->table, rhs->priv->table) != 0)) 	 
+		return FALSE; 	 
+  	 
+	if ((lhs->priv->table == 0) != (rhs->priv->table == 0)) 	 
+		return FALSE; 	 
+  	 
+	if ((lhs->priv->caption && rhs->priv->caption) 	 
+	    && (strcmp (lhs->priv->caption, rhs->priv->caption) != 0)) 	 
+		return FALSE; 	 
+  	 
+	if ((lhs->priv->caption == 0) != (rhs->priv->caption == 0)) 	 
+		return FALSE; 	 
+  	 
+	if ((lhs->priv->references && rhs->priv->references) 	 
+	    && (strcmp (lhs->priv->references, rhs->priv->references) != 0)) 	 
+		return FALSE; 	 
+  	 
+	if ((lhs->priv->references == 0) != (rhs->priv->references == 0)) 	 
+		return FALSE; 	 
+  	 
+	if (lhs->priv->default_value 	 
+	    && rhs->priv->default_value 	 
+	    && gda_value_compare (lhs->priv->default_value, rhs->priv->default_value) != 0) 	 
+		return FALSE; 	 
+  	 
+	if ((lhs->priv->default_value == 0) != (rhs->priv->default_value == 0)) 	 
+		return FALSE; 	 
+  	 
+	return TRUE; 	 
+ }
+
 /**
  * gda_column_get_defined_size
  * @column: a @GdaColumn.
@@ -231,9 +348,9 @@ gda_column_set_name (GdaColumn *column, const gchar *name)
 
 	g_return_if_fail (GDA_IS_COLUMN (column));
 
-	if (column->priv->name != NULL) {
-		old_name = g_strdup (column->priv->name);
-		g_free (column->priv->name);
+	if (column->priv->name) {
+		old_name = column->priv->name;
+		column->priv->name = NULL;
 	}
 
 	if (name)
@@ -242,6 +359,9 @@ gda_column_set_name (GdaColumn *column, const gchar *name)
 	g_signal_emit (G_OBJECT (column),
 		       gda_column_signals[NAME_CHANGED],
 		       0, old_name);
+
+	if (old_name)
+		g_free (old_name);
 }
 
 /**
@@ -380,8 +500,10 @@ gda_column_set_dbms_type (GdaColumn *column, const gchar *dbms_type)
 {
 	g_return_if_fail (GDA_IS_COLUMN (column));
 	
-	if (column->priv->dbms_type != NULL)
+	if (column->priv->dbms_type != NULL) {
 		g_free (column->priv->dbms_type);
+		column->priv->dbms_type = NULL;
+	}
 	
 	if (dbms_type)
 		column->priv->dbms_type = g_strdup (dbms_type);
@@ -533,8 +655,10 @@ gda_column_set_references (GdaColumn *column, const gchar *ref)
 {
 	g_return_if_fail (GDA_IS_COLUMN (column));
 
-	if (column->priv->references != NULL)
+	if (column->priv->references != NULL) {
 		g_free (column->priv->references);
+		column->priv->references = NULL;
+	}
 
 	if (ref)
 		column->priv->references = g_strdup (ref);
