@@ -57,6 +57,8 @@ struct _GdaColumnClass {
 
 GType           gda_column_get_type           (void);
 GdaColumn      *gda_column_new                (void);
+GdaColumn      *gda_column_copy               (GdaColumn *column);
+gboolean        gda_column_equal              (const GdaColumn *lhs, const GdaColumn *rhs);
 
 const gchar    *gda_column_get_title          (GdaColumn *column);
 void            gda_column_set_title          (GdaColumn *column, const gchar *title);
