@@ -1,5 +1,5 @@
 /* GDA Library
- * Copyright (C) 1998-2002 The GNOME Foundation.
+ * Copyright (C) 1998 - 2005 The GNOME Foundation.
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -51,6 +51,13 @@ gda_init (const gchar *app_id, const gchar *version, gint nargs, gchar *args[])
 	bindtextdomain (GETTEXT_PACKAGE, LIBGDA_LOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 
+	/* Threading support if possible */
+#ifdef G_THREADS_ENABLED
+#ifndef G_THREADS_IMPL_NONE
+	if (! g_thread_supported ())
+		g_thread_init (NULL);
+#endif
+#endif
 	g_type_init ();
 	g_set_prgname (app_id);
 
