@@ -43,13 +43,9 @@
 #include <libgda/gda-quark-list.h>
 #include <libgda/gda-row.h>
 #include <libgda/gda-select.h>
-#include <libgda/gda-table.h>
 #include <libgda/gda-transaction.h>
 #include <libgda/gda-util.h>
 #include <libgda/gda-value.h>
-#include <libgda/gda-xml-connection.h>
-#include <libgda/gda-xml-document.h>
-#include <libgda/gda-xml-database.h>
 #include <libgda/gda-enum-types.h>
   
 
