@@ -42,7 +42,7 @@ G_BEGIN_DECLS
  * Utility functions
  */
 
-GdaError *gda_freetds_make_error (TDSSOCKET *tds, const gchar *message);
+GdaConnectionEvent *gda_freetds_make_error (TDSSOCKET *tds, const gchar *message);
 gchar **gda_freetds_split_commandlist(const gchar *cmdlist);
 	
 
