@@ -31,7 +31,7 @@ plugin_get_name (void)
 const gchar *
 plugin_get_description (void)
 {
-	return _("GDA provider for Oracle databases");
+	return _("Provider for Oracle databases");
 }
 
 GList *
@@ -39,9 +39,10 @@ plugin_get_connection_params (void)
 {
 	GList *list = NULL;
 
-	list = g_list_append (list, g_strdup ("TNSNAME"));
-	list = g_list_append (list, g_strdup ("USERNAME"));
-	list = g_list_append (list, g_strdup ("PASSWORD"));
+	list = g_list_append (list,
+			      gda_provider_parameter_info_new_full ("TNSNAME", _("TNS Name"),
+								    _("Name of the TNS configuration to use for connecting"),
+								    GDA_VALUE_TYPE_STRING));
 
 	return list;
 }
