@@ -25,9 +25,11 @@
 #include <stdlib.h>
 #include <string.h>
 #include <libgda/gda-data-model-array.h>
+#include <libgda/gda-data-model-private.h>
 #include <libgda/gda-column-index.h>
 #include "gda-postgres.h"
 #include "gda-postgres-provider.h"
+#include "gda-postgres-blob.h"
 
 static void gda_postgres_provider_class_init (GdaPostgresProviderClass *klass);
 static void gda_postgres_provider_init       (GdaPostgresProvider *provider,
@@ -119,9 +121,10 @@ static GdaDataModel *gda_postgres_provider_get_schema (GdaServerProvider *provid
 						       GdaConnectionSchema schema,
 						       GdaParameterList *params);
 
-static gboolean gda_postgres_provider_create_blob (GdaServerProvider *provider,
-						   GdaConnection *cnc,
-						   GdaBlob *blob);
+static GdaBlob *gda_postgres_provider_create_blob (GdaServerProvider *provider,
+						   GdaConnection *cnc);
+static GdaBlob *gda_postgres_provider_fetch_blob (GdaServerProvider *provider,
+						  GdaConnection *cnc, const gchar *sql_id);
 
 gchar *
 gda_postgres_provider_value_to_sql_string (GdaServerProvider *provider, /* we dont actually use this!*/
@@ -129,8 +132,8 @@ gda_postgres_provider_value_to_sql_string (GdaServerProvider *provider, /* we do
 					GdaValue *from);
 				 		 
 typedef struct {
-	gchar *col_name;
-	GdaValueType data_type;
+	gchar        *col_name;
+	GdaValueType  data_type;
 } GdaPostgresColData;
 
 typedef struct {
@@ -186,6 +189,7 @@ gda_postgres_provider_class_init (GdaPostgresProviderClass *klass)
 	provider_class->supports = gda_postgres_provider_supports;
 	provider_class->get_schema = gda_postgres_provider_get_schema;
 	provider_class->create_blob = gda_postgres_provider_create_blob;
+	provider_class->fetch_blob = gda_postgres_provider_fetch_blob;
 	provider_class->value_to_sql_string = gda_postgres_provider_value_to_sql_string;
 }
 
@@ -455,7 +459,7 @@ gda_postgres_provider_get_version (GdaServerProvider *provider)
 	return PACKAGE_VERSION;
 }
 
-/* get the float version og a Postgres version which looks like:
+/* get the float version of a Postgres version which looks like:
  * PostgreSQL 7.2.2 on i686-pc-linux-gnu, compiled by GCC 2.96 => returns 7.22
  * PostgreSQL 7.3 on i686-pc-linux-gnu, compiled by GCC 2.95.3 => returns 7.3
  * WARNING: no serious test is made on the validity of the string
@@ -488,6 +492,7 @@ get_pg_version_float (const gchar *str)
 	return retval;
 }
 
+
 /* open_connection handler for the GdaPostgresProvider class */
 static gboolean
 gda_postgres_provider_open_connection (GdaServerProvider *provider,
@@ -1474,6 +1479,7 @@ gda_postgres_init_procs_recset (GdaConnection *cnc)
 {
 	GdaDataModelArray *recset;
 	gint i;
+	GdaColumn *column;
 	GdaPostgresColData cols[8] = {
 		{ N_("Procedure")	, GDA_VALUE_TYPE_STRING  },
 		{ N_("Id")              , GDA_VALUE_TYPE_STRING  },
@@ -1486,8 +1492,12 @@ gda_postgres_init_procs_recset (GdaConnection *cnc)
 		};
 
 	recset = GDA_DATA_MODEL_ARRAY (gda_data_model_array_new (sizeof cols / sizeof cols[0]));
-	for (i = 0; i < sizeof cols / sizeof cols[0]; i++)
-		gda_data_model_set_column_title (GDA_DATA_MODEL (recset), i, _(cols[i].col_name));
+	for (i = 0; i < sizeof cols / sizeof cols[0]; i++) {
+		column = gda_data_model_describe_column (GDA_DATA_MODEL (recset), i);
+		
+		gda_column_set_title (column, _(cols[i].col_name));
+		gda_column_set_gdatype (column, cols[i].data_type);
+	}
 
 	return recset;
 }
@@ -1762,6 +1772,15 @@ get_postgres_types (GdaConnection *cnc, GdaParameterList *params)
 	gint i;
 	static GHashTable *synonyms = NULL;
 
+	GdaColumn *column;
+	GdaPostgresColData cols[5] = {
+		{ N_("Type")	           , GDA_VALUE_TYPE_STRING  },
+		{ N_("Owner")              , GDA_VALUE_TYPE_STRING  },
+		{ N_("Comments")	   , GDA_VALUE_TYPE_STRING  },
+		{ N_("GDA type")       	   , GDA_VALUE_TYPE_TYPE  },
+		{ N_("Synonyms")	   , GDA_VALUE_TYPE_STRING  }
+		};
+
 	if (!synonyms) {
 		synonyms = g_hash_table_new (g_str_hash, g_str_equal);
 
@@ -1782,12 +1801,13 @@ get_postgres_types (GdaConnection *cnc, GdaParameterList *params)
 	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), NULL);
 
 	/* create the recordset */
-	recset = GDA_DATA_MODEL_ARRAY (gda_data_model_array_new (5));
-	gda_data_model_set_column_title (GDA_DATA_MODEL (recset), 0, _("Type"));
-	gda_data_model_set_column_title (GDA_DATA_MODEL (recset), 1, _("Owner"));
-	gda_data_model_set_column_title (GDA_DATA_MODEL (recset), 2, _("Comments"));
-	gda_data_model_set_column_title (GDA_DATA_MODEL (recset), 3, _("GDA type"));
-	gda_data_model_set_column_title (GDA_DATA_MODEL (recset), 4, _("Synonyms"));
+	recset = GDA_DATA_MODEL_ARRAY (gda_data_model_array_new (sizeof cols / sizeof cols[0]));
+	for (i = 0; i < sizeof cols / sizeof cols[0]; i++) {
+		column = gda_data_model_describe_column (GDA_DATA_MODEL (recset), i);
+		
+		gda_column_set_title (column, _(cols[i].col_name));
+		gda_column_set_gdatype (column, cols[i].data_type);
+	}
 
 	/* fill the recordset */
 	priv_data = g_object_get_data (G_OBJECT (cnc), OBJECT_DATA_POSTGRES_HANDLE);
@@ -1846,6 +1866,7 @@ get_postgres_views (GdaConnection *cnc, GdaParameterList *params)
 
 	recset = GDA_DATA_MODEL (reclist->data);
 	g_list_free (reclist);
+
 	/* Set it here instead of the SQL query to allow i18n */
 	gda_data_model_set_column_title (recset, 0, _("View"));
 	gda_data_model_set_column_title (recset, 1, _("Owner"));
@@ -2015,6 +2036,7 @@ gda_postgres_init_md_recset (GdaConnection *cnc)
 {
 	GdaDataModelArray *recset;
 	gint i;
+	GdaColumn *column;
 	GdaPostgresColData cols[] = {
 		{ N_("Field name")	, GDA_VALUE_TYPE_STRING  },
 		{ N_("Data type")	, GDA_VALUE_TYPE_STRING  },
@@ -2029,8 +2051,12 @@ gda_postgres_init_md_recset (GdaConnection *cnc)
 		};
 
 	recset = GDA_DATA_MODEL_ARRAY (gda_data_model_array_new (sizeof cols / sizeof cols[0]));
-	for (i = 0; i < sizeof cols / sizeof cols[0]; i++)
-		gda_data_model_set_column_title (GDA_DATA_MODEL (recset), i, _(cols[i].col_name));
+	for (i = 0; i < sizeof cols / sizeof cols[0]; i++) {
+		column = gda_data_model_describe_column (GDA_DATA_MODEL (recset), i);
+		
+		gda_column_set_title (column, _(cols[i].col_name));
+		gda_column_set_gdatype (column, cols[i].data_type);
+	}
 
 	return recset;
 }
@@ -2051,13 +2077,14 @@ gda_postgres_get_idx_data (GdaPostgresConnectionData *priv_data, const gchar *tb
 					 "AND i.indexrelid = c2.oid", tblname);
 	else
 		query = g_strdup_printf ("SELECT i.indkey, i.indisprimary, i.indisunique "
+					 /*",pg_get_indexdef (i.indexrelid, 1, false) ": to get index definition */
 					 "FROM pg_catalog.pg_class c, pg_catalog.pg_class c2, pg_catalog.pg_index i "
 					 "WHERE c.relname = '%s' "
 					 "AND c.oid = i.indrelid "
 					 "AND i.indexrelid = c2.oid "
-					 "AND pg_catalog.pg_table_is_visible(c.oid)", tblname);
+					 "AND pg_catalog.pg_table_is_visible(c.oid) AND i.indkey [0] <> 0", tblname);
 
-	pg_idx = PQexec(priv_data->pconn, query);
+	pg_idx = PQexec (priv_data->pconn, query);
 	g_free (query);
 	if (pg_idx == NULL)
 		return NULL;
@@ -2071,8 +2098,10 @@ gda_postgres_get_idx_data (GdaPostgresConnectionData *priv_data, const gchar *tb
 		gchar *value;
 		gint k;
 
-		arr = g_strsplit (PQgetvalue (pg_idx, i, 0), " ", 0);
-		if (arr == NULL || arr[0][0] == '\0') {
+		value = PQgetvalue (pg_idx, i, 0);
+		if (value && *value) 
+			arr = g_strsplit (value, " ", 0);
+		else {
 			idx_data[i].ncolumns = 0;
 			continue;
 		}
@@ -2609,6 +2638,7 @@ get_postgres_sequences (GdaConnection *cnc, GdaParameterList *params)
 
 	recset = GDA_DATA_MODEL (reclist->data);
 	g_list_free (reclist);
+
 	/* Set it here instead of the SQL query to allow i18n */
 	gda_data_model_set_column_title (recset, 0, _("Sequence"));
 	gda_data_model_set_column_title (recset, 1, _("Owner"));
@@ -2713,14 +2743,24 @@ gda_postgres_provider_get_schema (GdaServerProvider *provider,
 	return NULL;
 }
 
-static gboolean gda_postgres_provider_create_blob (GdaServerProvider *provider,
-						   GdaConnection *cnc,
-						   GdaBlob *blob)
+static GdaBlob *
+gda_postgres_provider_create_blob (GdaServerProvider *provider,
+				   GdaConnection *cnc)
 {
 	g_return_val_if_fail (GDA_IS_SERVER_PROVIDER (provider), FALSE);
 	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), FALSE);
 
-	return gda_postgres_blob_create (blob, cnc);
+	return gda_postgres_blob_new (cnc);
+}
+
+static GdaBlob *
+gda_postgres_provider_fetch_blob (GdaServerProvider *provider,
+				  GdaConnection *cnc, const gchar *sql_id)
+{
+	g_return_val_if_fail (GDA_IS_SERVER_PROVIDER (provider), FALSE);
+	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), FALSE);
+
+	return gda_postgres_blob_new_with_id (cnc, sql_id);
 }
 
 gchar *
