@@ -1,8 +1,9 @@
 /* GDA - Test suite
- * Copyright (C) 1998-2002 The GNOME Foundation
+ * Copyright (C) 1998 - 2005 The GNOME Foundation
  *
  * AUTHORS:
  *	Rodrigo Moya <rodrigo@gnome-db.org>
+ *      Vivien Malerba <malerba@gnome-db.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -55,8 +56,12 @@ show_schema (GdaConnection *cnc, GdaConnectionSchema schema, const gchar *label)
 
 			value = gda_data_model_get_value_at (model, c, r);
 			str = gda_value_stringify ((GdaValue *) value);
-			g_print ("\t%s", str);
-			g_free (str);
+			if (str) {
+				g_print ("\t%s", str);
+				g_free (str);
+			} else {
+				g_print("\t??NULL??");
+			}
 		}
 		g_print ("\n");
 	}
@@ -78,7 +83,7 @@ open_connection (GdaClient *client,
 
 	g_return_if_fail (GDA_IS_CLIENT (client));
 
-	cnc = gda_client_open_connection (client, name, username, password, 0);
+	cnc = gda_client_open_connection (client, name, username, password, 0, NULL);
 	if (!GDA_IS_CONNECTION (cnc)) {
 		g_print (_("** ERROR: could not open connection to %s\n"), name);
 		return;
@@ -171,7 +176,7 @@ open_connection (GdaClient *client,
 	if (!strcmp (dsn_info->provider, IBMDB2_PROVIDER_NAME))
 		do_ibmdb2_test (cnc);
 		
-	gda_config_free_data_source_info (dsn_info);
+	gda_data_source_info_free (dsn_info);
 
 	/* close the connection */
 	gda_connection_close (cnc);
